# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='base_gcmessages.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x15\x62\x61se_gcmessages.proto\x1a\x13steammessages.proto\"\x9a\x01\n\x1d\x43GCStorePurchaseInit_LineItem\x12\x13\n\x0bitem_def_id\x18\x01 \x01(\r\x12\x10\n\x08quantity\x18\x02 \x01(\r\x12\x1e\n\x16\x63ost_in_local_currency\x18\x03 \x01(\r\x12\x15\n\rpurchase_type\x18\x04 \x01(\r\x12\x1b\n\x13source_reference_id\x18\x05 \x01(\x04\"\x82\x01\n\x17\x43MsgGCStorePurchaseInit\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x03 \x01(\x05\x12\x32\n\nline_items\x18\x04 \x03(\x0b\x32\x1e.CGCStorePurchaseInit_LineItem\"A\n\x1f\x43MsgGCStorePurchaseInitResponse\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06txn_id\x18\x02 \x01(\x04\"&\n\x13\x43MsgSystemBroadcast\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x9e\x01\n\x12\x43MsgClientPingData\x12\x17\n\x0brelay_codes\x18\x04 \x03(\x07\x42\x02\x10\x01\x12\x17\n\x0brelay_pings\x18\x05 \x03(\rB\x02\x10\x01\x12\x18\n\x0cregion_codes\x18\x08 \x03(\rB\x02\x10\x01\x12\x18\n\x0cregion_pings\x18\t \x03(\rB\x02\x10\x01\x12\"\n\x1aregion_ping_failed_bitmask\x18\n \x01(\r\"\x88\x01\n\x11\x43MsgInviteToParty\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\x12\x0f\n\x07team_id\x18\x03 \x01(\r\x12\x10\n\x08\x61s_coach\x18\x04 \x01(\x08\x12&\n\tping_data\x18\x05 \x01(\x0b\x32\x13.CMsgClientPingData\"=\n\x11\x43MsgInviteToLobby\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x16\n\x0e\x63lient_version\x18\x02 \x01(\r\"Q\n\x15\x43MsgInvitationCreated\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\x10\n\x08steam_id\x18\x02 \x01(\x06\x12\x14\n\x0cuser_offline\x18\x03 \x01(\x08\"{\n\x17\x43MsgPartyInviteResponse\x12\x10\n\x08party_id\x18\x01 \x01(\x04\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12&\n\tping_data\x18\x08 \x01(\x0b\x32\x13.CMsgClientPingData\"\x8b\x01\n\x17\x43MsgLobbyInviteResponse\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x02 \x01(\x08\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\r\x12\x17\n\x0f\x63ustom_game_crc\x18\x06 \x01(\x06\x12\x1d\n\x15\x63ustom_game_timestamp\x18\x07 \x01(\x07\"%\n\x11\x43MsgKickFromParty\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\"\x10\n\x0e\x43MsgLeaveParty\"\xa2\x01\n\x1b\x43MsgCustomGameInstallStatus\x12M\n\x06status\x18\x01 \x01(\x0e\x32\x19.ECustomGameInstallStatus:\"k_ECustomGameInstallStatus_Unknown\x12\x0f\n\x07message\x18\x02 \x01(\t\x12#\n\x1blatest_timestamp_from_steam\x18\x03 \x01(\x07\"W\n\x13\x43MsgServerAvailable\x12@\n\x1a\x63ustom_game_install_status\x18\x01 \x01(\x0b\x32\x1c.CMsgCustomGameInstallStatus\"*\n\x16\x43MsgLANServerAvailable\x12\x10\n\x08lobby_id\x18\x01 \x01(\x06\"\xaa\x02\n\x18\x43SOEconGameAccountClient\x12$\n\x19\x61\x64\x64itional_backpack_slots\x18\x01 \x01(\r:\x01\x30\x12\x1c\n\rtrial_account\x18\x02 \x01(\x08:\x05\x66\x61lse\x12&\n\x18\x65ligible_for_online_play\x18\x03 \x01(\x08:\x04true\x12*\n\"need_to_choose_most_helpful_friend\x18\x04 \x01(\x08\x12\x17\n\x0fin_coaches_list\x18\x05 \x01(\x08\x12\x1c\n\x14trade_ban_expiration\x18\x06 \x01(\x07\x12\x1b\n\x13\x64uel_ban_expiration\x18\x07 \x01(\x07\x12\"\n\x13made_first_purchase\x18\t \x01(\x08:\x05\x66\x61lse\"r\n\x18\x43SOItemCriteriaCondition\x12\n\n\x02op\x18\x01 \x01(\x05\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x13\n\x0b\x66loat_value\x18\x04 \x01(\x02\x12\x14\n\x0cstring_value\x18\x05 \x01(\t\"\x83\x02\n\x0f\x43SOItemCriteria\x12\x12\n\nitem_level\x18\x01 \x01(\r\x12\x14\n\x0citem_quality\x18\x02 \x01(\x05\x12\x16\n\x0eitem_level_set\x18\x03 \x01(\x08\x12\x18\n\x10item_quality_set\x18\x04 \x01(\x08\x12\x19\n\x11initial_inventory\x18\x05 \x01(\r\x12\x18\n\x10initial_quantity\x18\x06 \x01(\r\x12\x1b\n\x13ignore_enabled_flag\x18\x08 \x01(\x08\x12-\n\nconditions\x18\t \x03(\x0b\x32\x19.CSOItemCriteriaCondition\x12\x13\n\x0brecent_only\x18\n \x01(\x08\"\xd5\x03\n\rCSOItemRecipe\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03n_a\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65sc_inputs\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65sc_outputs\x18\x05 \x01(\t\x12\x0c\n\x04\x64i_a\x18\x06 \x01(\t\x12\x0c\n\x04\x64i_b\x18\x07 \x01(\t\x12\x0c\n\x04\x64i_c\x18\x08 \x01(\t\x12\x0c\n\x04\x64o_a\x18\t \x01(\t\x12\x0c\n\x04\x64o_b\x18\n \x01(\t\x12\x0c\n\x04\x64o_c\x18\x0b \x01(\t\x12\x1f\n\x17requires_all_same_class\x18\x0c \x01(\x08\x12\x1e\n\x16requires_all_same_slot\x18\r \x01(\x08\x12\x1e\n\x16\x63lass_usage_for_output\x18\x0e \x01(\x05\x12\x1d\n\x15slot_usage_for_output\x18\x0f \x01(\x05\x12\x16\n\x0eset_for_output\x18\x10 \x01(\x05\x12.\n\x14input_items_criteria\x18\x14 \x03(\x0b\x32\x10.CSOItemCriteria\x12/\n\x15output_items_criteria\x18\x15 \x03(\x0b\x32\x10.CSOItemCriteria\x12\x1e\n\x16input_item_dupe_counts\x18\x16 \x03(\r\"J\n\x14\x43MsgApplyStrangePart\x12\x1c\n\x14strange_part_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\"K\n\x17\x43MsgApplyPennantUpgrade\x12\x17\n\x0fupgrade_item_id\x18\x01 \x01(\x04\x12\x17\n\x0fpennant_item_id\x18\x02 \x01(\x04\"C\n\x13\x43MsgApplyEggEssence\x12\x17\n\x0f\x65ssence_item_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x65gg_item_id\x18\x02 \x01(\x04\"M\n\x14\x43SOEconItemAttribute\x12\x11\n\tdef_index\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x13\n\x0bvalue_bytes\x18\x03 \x01(\x0c\":\n\x13\x43SOEconItemEquipped\x12\x11\n\tnew_class\x18\x01 \x01(\r\x12\x10\n\x08new_slot\x18\x02 \x01(\r\"\xf1\x02\n\x0b\x43SOEconItem\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x12\n\naccount_id\x18\x02 \x01(\r\x12\x11\n\tinventory\x18\x03 \x01(\r\x12\x11\n\tdef_index\x18\x04 \x01(\r\x12\x13\n\x08quantity\x18\x05 \x01(\r:\x01\x31\x12\x10\n\x05level\x18\x06 \x01(\r:\x01\x31\x12\x12\n\x07quality\x18\x07 \x01(\r:\x01\x34\x12\x10\n\x05\x66lags\x18\x08 \x01(\r:\x01\x30\x12\x11\n\x06origin\x18\t \x01(\r:\x01\x30\x12(\n\tattribute\x18\x0c \x03(\x0b\x32\x15.CSOEconItemAttribute\x12#\n\rinterior_item\x18\r \x01(\x0b\x32\x0c.CSOEconItem\x12\x15\n\x06in_use\x18\x0e \x01(\x08:\x05\x66\x61lse\x12\x10\n\x05style\x18\x0f \x01(\r:\x01\x30\x12\x16\n\x0boriginal_id\x18\x10 \x01(\x04:\x01\x30\x12,\n\x0e\x65quipped_state\x18\x12 \x03(\x0b\x32\x14.CSOEconItemEquipped\"\"\n\rCMsgSortItems\x12\x11\n\tsort_type\x18\x01 \x01(\r\"^\n\x10\x43SOEconClaimCode\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tcode_type\x18\x02 \x01(\r\x12\x15\n\rtime_acquired\x18\x03 \x01(\r\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\"3\n\x14\x43MsgStoreGetUserData\x12\x1b\n\x13price_sheet_version\x18\x01 \x01(\x07\"\x94\x02\n\x1c\x43MsgStoreGetUserDataResponse\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x10\n\x08\x63urrency\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x1b\n\x13price_sheet_version\x18\x04 \x01(\x07\x12\x1a\n\x0f\x65xperiment_data\x18\x05 \x01(\x04:\x01\x30\x12\x19\n\x11\x66\x65\x61tured_item_idx\x18\x06 \x01(\x05\x12#\n\x15show_hat_descriptions\x18\x07 \x01(\x08:\x04true\x12\x13\n\x0bprice_sheet\x18\x08 \x01(\x0c\x12\x1c\n\x11\x64\x65\x66\x61ult_item_sort\x18\t \x01(\x05:\x01\x30\x12\x15\n\rpopular_items\x18\n \x03(\r\"_\n\x14\x43MsgUpdateItemSchema\x12\x12\n\nitems_game\x18\x01 \x01(\x0c\x12\x1b\n\x13item_schema_version\x18\x02 \x01(\x07\x12\x16\n\x0eitems_game_url\x18\x03 \x01(\t\"!\n\x0b\x43MsgGCError\x12\x12\n\nerror_text\x18\x01 \x01(\t\"\x1d\n\x1b\x43MsgRequestInventoryRefresh\".\n\x0f\x43MsgConVarValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"9\n\x14\x43MsgReplicateConVars\x12!\n\x07\x63onvars\x18\x01 \x03(\x0b\x32\x10.CMsgConVarValue\".\n\x17\x43MsgConsumableExhausted\x12\x13\n\x0bitem_def_id\x18\x01 \x01(\x05\"\x81\x01\n\x14\x43MsgItemAcknowledged\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tinventory\x18\x02 \x01(\r\x12\x11\n\tdef_index\x18\x03 \x01(\r\x12\x0f\n\x07quality\x18\x04 \x01(\r\x12\x0e\n\x06rarity\x18\x05 \x01(\r\x12\x0e\n\x06origin\x18\x06 \x01(\r\"\x85\x01\n\x14\x43MsgSetItemPositions\x12:\n\x0eitem_positions\x18\x01 \x03(\x0b\x32\".CMsgSetItemPositions.ItemPosition\x1a\x31\n\x0cItemPosition\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x10\n\x08position\x18\x02 \x01(\r\"f\n\x1a\x43MsgGCNameItemNotification\x12\x16\n\x0eplayer_steamid\x18\x01 \x01(\x06\x12\x16\n\x0eitem_def_index\x18\x02 \x01(\r\x12\x18\n\x10item_name_custom\x18\x03 \x01(\t\"\xb6\x01\n\x1f\x43MsgGCClientDisplayNotification\x12+\n#notification_title_localization_key\x18\x01 \x01(\t\x12*\n\"notification_body_localization_key\x18\x02 \x01(\t\x12\x1b\n\x13\x62ody_substring_keys\x18\x03 \x03(\t\x12\x1d\n\x15\x62ody_substring_values\x18\x04 \x03(\t\"1\n\x17\x43MsgGCShowItemsPickedUp\x12\x16\n\x0eplayer_steamid\x18\x01 \x01(\x06\"|\n CMsgGCIncrementKillCountResponse\x12\x1f\n\x11killer_account_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x11\n\tnum_kills\x18\x02 \x01(\r\x12\x10\n\x08item_def\x18\x03 \x01(\r\x12\x12\n\nlevel_type\x18\x04 \x01(\r\"\xcd\x01\n\x18\x43SOEconItemDropRateBonus\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x17\n\x0f\x65xpiration_date\x18\x02 \x01(\x07\x12\x13\n\x05\x62onus\x18\x03 \x01(\x02\x42\x04\x80\x97\"\x01\x12\x13\n\x0b\x62onus_count\x18\x04 \x01(\r\x12\x0f\n\x07item_id\x18\x05 \x01(\x04\x12\x11\n\tdef_index\x18\x06 \x01(\r\x12\x14\n\x0cseconds_left\x18\x07 \x01(\r\x12\x1a\n\x0c\x62ooster_type\x18\x08 \x01(\rB\x04\x80\x97\"\x01\"w\n\x19\x43SOEconItemLeagueViewPass\x12\x18\n\naccount_id\x18\x01 \x01(\rB\x04\x80\x97\"\x01\x12\x17\n\tleague_id\x18\x02 \x01(\rB\x04\x80\x97\"\x01\x12\x11\n\titemindex\x18\x04 \x01(\r\x12\x14\n\x0cgrant_reason\x18\x05 \x01(\r\"O\n\x16\x43SOEconItemEventTicket\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\"\xca\x01\n\x1d\x43SOEconItemTournamentPassport\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\tleague_id\x18\x02 \x01(\r\x12\x0f\n\x07item_id\x18\x03 \x01(\x04\x12\x1d\n\x15original_purchaser_id\x18\x04 \x01(\r\x12\x18\n\x10passports_bought\x18\x05 \x01(\r\x12\x0f\n\x07version\x18\x06 \x01(\r\x12\x11\n\tdef_index\x18\x07 \x01(\r\x12\x14\n\x0creward_flags\x18\x08 \x01(\r\"+\n\x19\x43MsgGCStorePurchaseCancel\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\"3\n!CMsgGCStorePurchaseCancelResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1b\x43MsgGCStorePurchaseFinalize\x12\x0e\n\x06txn_id\x18\x01 \x01(\x04\"G\n#CMsgGCStorePurchaseFinalizeResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x10\n\x08item_ids\x18\x02 \x03(\x04\"I\n\x1b\x43MsgGCBannedWordListRequest\x12\x19\n\x11\x62\x61n_list_group_id\x18\x01 \x01(\r\x12\x0f\n\x07word_id\x18\x02 \x01(\r\"u\n\x10\x43MsgGCBannedWord\x12\x0f\n\x07word_id\x18\x01 \x01(\r\x12\x42\n\tword_type\x18\x02 \x01(\x0e\x32\x12.GC_BannedWordType:\x1bGC_BANNED_WORD_DISABLE_WORD\x12\x0c\n\x04word\x18\x03 \x01(\t\"_\n\x1c\x43MsgGCBannedWordListResponse\x12\x19\n\x11\x62\x61n_list_group_id\x18\x01 \x01(\r\x12$\n\tword_list\x18\x02 \x03(\x0b\x32\x11.CMsgGCBannedWord\"U\n!CMsgGCToGCBannedWordListBroadcast\x12\x30\n\tbroadcast\x18\x01 \x01(\x0b\x32\x1d.CMsgGCBannedWordListResponse\"3\n\x1f\x43MsgGCToGCBannedWordListUpdated\x12\x10\n\x08group_id\x18\x01 \x01(\r\"?\n\x17\x43MsgGCToGCDirtySDOCache\x12\x10\n\x08sdo_type\x18\x01 \x01(\r\x12\x12\n\nkey_uint64\x18\x02 \x01(\x04\"G\n\x1f\x43MsgGCToGCDirtyMultipleSDOCache\x12\x10\n\x08sdo_type\x18\x01 \x01(\r\x12\x12\n\nkey_uint64\x18\x02 \x03(\x04\"H\n\x1f\x43MsgGCToGCApplyLocalizationDiff\x12\x10\n\x08language\x18\x01 \x01(\r\x12\x13\n\x0bpacked_diff\x18\x02 \x01(\t\":\n\'CMsgGCToGCApplyLocalizationDiffResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"H\n\x11\x43MsgGCCollectItem\x12\x1a\n\x12\x63ollection_item_id\x18\x01 \x01(\x04\x12\x17\n\x0fsubject_item_id\x18\x02 \x01(\x04\"\x14\n\x12\x43MsgSDONoMemcached\"/\n\x1b\x43MsgGCToGCUpdateSQLKeyValue\x12\x10\n\x08key_name\x18\x01 \x01(\t\"4\n\x1a\x43MsgGCServerVersionUpdated\x12\x16\n\x0eserver_version\x18\x01 \x01(\r\"4\n\x1a\x43MsgGCClientVersionUpdated\x12\x16\n\x0e\x63lient_version\x18\x01 \x01(\r\" \n\x1e\x43MsgGCToGCWebAPIAccountChanged\"G\n\x13\x43MsgRecipeComponent\x12\x17\n\x0fsubject_item_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x61ttribute_index\x18\x02 \x01(\x04\"o\n!CMsgFulfillDynamicRecipeComponent\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x34\n\x16\x63onsumption_components\x18\x02 \x03(\x0b\x32\x14.CMsgRecipeComponent\"6\n\x1d\x43MsgGCClientMarketDataRequest\x12\x15\n\ruser_currency\x18\x01 \x01(\r\"\x88\x01\n\x1b\x43MsgGCClientMarketDataEntry\x12\x16\n\x0eitem_def_index\x18\x01 \x01(\r\x12\x14\n\x0citem_quality\x18\x02 \x01(\r\x12\x1a\n\x12item_sell_listings\x18\x03 \x01(\r\x12\x1f\n\x17price_in_local_currency\x18\x04 \x01(\r\"G\n\x16\x43MsgGCClientMarketData\x12-\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1c.CMsgGCClientMarketDataEntry\"\\\n\x0f\x43MsgExtractGems\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\x12\x1d\n\x0eitem_socket_id\x18\x03 \x01(\r:\x05\x36\x35\x35\x33\x35\"\xd4\x02\n\x17\x43MsgExtractGemsResponse\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12P\n\x08response\x18\x02 \x01(\x0e\x32%.CMsgExtractGemsResponse.EExtractGems:\x17k_ExtractGems_Succeeded\"\xd5\x01\n\x0c\x45\x45xtractGems\x12\x1b\n\x17k_ExtractGems_Succeeded\x10\x00\x12&\n\"k_ExtractGems_Failed_ToolIsInvalid\x10\x01\x12&\n\"k_ExtractGems_Failed_ItemIsInvalid\x10\x02\x12,\n(k_ExtractGems_Failed_ToolCannotRemoveGem\x10\x03\x12*\n&k_ExtractGems_Failed_FailedToRemoveGem\x10\x04\"L\n\rCMsgAddSocket\x12\x14\n\x0ctool_item_id\x18\x01 \x01(\x04\x12\x14\n\x0citem_item_id\x18\x02 \x01(\x04\x12\x0f\n\x07unusual\x18\x03 \x01(\x08\"\xb9\x02\n\x15\x43MsgAddSocketResponse\x12\x0f\n\x07item_id\x18\x01 \x01(\x04\x12\x1c\n\x14updated_socket_index\x18\x02 \x03(\r\x12J\n\x08response\x18\x03 \x01(\x0e\x32!.CMsgAddSocketResponse.EAddSocket:\x15k_AddSocket_Succeeded\"\xa4\x01\n\nEAddSocket\x12\x19\n\x15k_AddSocket_Succeeded\x10\x00\x12$\n k_AddSocket_Failed_ToolIsInvalid\x10\x01\x12+\n\'k_AddSocket_Failed_ItemCannotBeSocketed\x10\x02\x12(\n$k_AddSocket_Failed_FailedToAddSocket\x10\x03\"D\n\x17\x43MsgAddItemToSocketData\x12\x13\n\x0bgem_item_id\x18\x01 \x01(\x04\x12\x14\n\x0csocket_index\x18\x02 \x01(\r\"]\n\x13\x43MsgAddItemToSocket\x12\x14\n\x0citem_item_id\x18\x01 \x01(\x04\x12\x30\n\x0egems_to_socket\x18\x02 \x03(\x0b\x32\x18.CMsgAddItemToSocketData\"\xdf\x03\n\x1b\x43MsgAddItemToSocketResponse\x12\x14\n\x0citem_item_id\x18\x01 \x01(\x04\x12\x1c\n\x14updated_socket_index\x18\x02 \x03(\r\x12J\n\x08response\x18\x03 \x01(\x0e\x32$.CMsgAddItemToSocketResponse.EAddGem:\x12k_AddGem_Succeeded\"\xbf\x02\n\x07\x45\x41\x64\x64Gem\x12\x16\n\x12k_AddGem_Succeeded\x10\x00\x12 \n\x1ck_AddGem_Failed_GemIsInvalid\x10\x01\x12!\n\x1dk_AddGem_Failed_ItemIsInvalid\x10\x02\x12\"\n\x1ek_AddGem_Failed_FailedToAddGem\x10\x03\x12+\n\'k_AddGem_Failed_InvalidGemTypeForSocket\x10\x04\x12)\n%k_AddGem_Failed_InvalidGemTypeForHero\x10\x05\x12)\n%k_AddGem_Failed_InvalidGemTypeForSlot\x10\x06\x12\x30\n,k_AddGem_Failed_SocketContainsUnremovableGem\x10\x07\"F\n\x18\x43MsgResetStrangeGemCount\x12\x14\n\x0citem_item_id\x18\x01 \x01(\x04\x12\x14\n\x0csocket_index\x18\x02 \x01(\r\"\xbe\x02\n CMsgResetStrangeGemCountResponse\x12S\n\x08response\x18\x01 \x01(\x0e\x32+.CMsgResetStrangeGemCountResponse.EResetGem:\x14k_ResetGem_Succeeded\"\xc4\x01\n\tEResetGem\x12\x18\n\x14k_ResetGem_Succeeded\x10\x00\x12&\n\"k_ResetGem_Failed_FailedToResetGem\x10\x01\x12#\n\x1fk_ResetGem_Failed_ItemIsInvalid\x10\x02\x12%\n!k_ResetGem_Failed_InvalidSocketId\x10\x03\x12)\n%k_ResetGem_Failed_SocketCannotBeReset\x10\x04*\xc8\x03\n\nEGCBaseMsg\x12\x1a\n\x15k_EMsgGCSystemMessage\x10\xa1\x1f\x12\x1d\n\x18k_EMsgGCReplicateConVars\x10\xa2\x1f\x12\x1a\n\x15k_EMsgGCConVarUpdated\x10\xa3\x1f\x12\x1a\n\x15k_EMsgGCInviteToParty\x10\x95#\x12\x1e\n\x19k_EMsgGCInvitationCreated\x10\x96#\x12 \n\x1bk_EMsgGCPartyInviteResponse\x10\x97#\x12\x1a\n\x15k_EMsgGCKickFromParty\x10\x98#\x12\x17\n\x12k_EMsgGCLeaveParty\x10\x99#\x12\x1c\n\x17k_EMsgGCServerAvailable\x10\x9a#\x12\"\n\x1dk_EMsgGCClientConnectToServer\x10\x9b#\x12\x1b\n\x16k_EMsgGCGameServerInfo\x10\x9c#\x12\x12\n\rk_EMsgGCError\x10\x9d#\x12\x1f\n\x1ak_EMsgGCLANServerAvailable\x10\x9f#\x12\x1a\n\x15k_EMsgGCInviteToLobby\x10\xa0#\x12 \n\x1bk_EMsgGCLobbyInviteResponse\x10\xa1#*Y\n\x17\x45GCBaseProtoObjectTypes\x12\x1e\n\x19k_EProtoObjectPartyInvite\x10\xe9\x07\x12\x1e\n\x19k_EProtoObjectLobbyInvite\x10\xea\x07*\xe8\x03\n\x18\x45\x43ustomGameInstallStatus\x12&\n\"k_ECustomGameInstallStatus_Unknown\x10\x00\x12$\n k_ECustomGameInstallStatus_Ready\x10\x01\x12#\n\x1fk_ECustomGameInstallStatus_Busy\x10\x02\x12,\n(k_ECustomGameInstallStatus_FailedGeneric\x10\x65\x12\x32\n.k_ECustomGameInstallStatus_FailedInternalError\x10\x66\x12\x37\n3k_ECustomGameInstallStatus_RequestedTimestampTooOld\x10g\x12\x37\n3k_ECustomGameInstallStatus_RequestedTimestampTooNew\x10h\x12*\n&k_ECustomGameInstallStatus_CRCMismatch\x10i\x12*\n&k_ECustomGameInstallStatus_FailedSteam\x10j\x12-\n)k_ECustomGameInstallStatus_FailedCanceled\x10k*T\n\x11GC_BannedWordType\x12\x1f\n\x1bGC_BANNED_WORD_DISABLE_WORD\x10\x00\x12\x1e\n\x1aGC_BANNED_WORD_ENABLE_WORD\x10\x01\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCBASEMSG = _descriptor.EnumDescriptor(
  name='EGCBaseMsg',
  full_name='EGCBaseMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCSystemMessage', index=0, number=4001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCReplicateConVars', index=1, number=4002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCConVarUpdated', index=2, number=4003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInviteToParty', index=3, number=4501,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInvitationCreated', index=4, number=4502,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCPartyInviteResponse', index=5, number=4503,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCKickFromParty', index=6, number=4504,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLeaveParty', index=7, number=4505,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCServerAvailable', index=8, number=4506,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCClientConnectToServer', index=9, number=4507,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGameServerInfo', index=10, number=4508,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCError', index=11, number=4509,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLANServerAvailable', index=12, number=4511,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCInviteToLobby', index=13, number=4512,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCLobbyInviteResponse', index=14, number=4513,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9060,
  serialized_end=9516,
)
_sym_db.RegisterEnumDescriptor(_EGCBASEMSG)

EGCBaseMsg = enum_type_wrapper.EnumTypeWrapper(_EGCBASEMSG)
_EGCBASEPROTOOBJECTTYPES = _descriptor.EnumDescriptor(
  name='EGCBaseProtoObjectTypes',
  full_name='EGCBaseProtoObjectTypes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EProtoObjectPartyInvite', index=0, number=1001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EProtoObjectLobbyInvite', index=1, number=1002,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9518,
  serialized_end=9607,
)
_sym_db.RegisterEnumDescriptor(_EGCBASEPROTOOBJECTTYPES)

EGCBaseProtoObjectTypes = enum_type_wrapper.EnumTypeWrapper(_EGCBASEPROTOOBJECTTYPES)
_ECUSTOMGAMEINSTALLSTATUS = _descriptor.EnumDescriptor(
  name='ECustomGameInstallStatus',
  full_name='ECustomGameInstallStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_Unknown', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_Ready', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_Busy', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedGeneric', index=3, number=101,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedInternalError', index=4, number=102,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_RequestedTimestampTooOld', index=5, number=103,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_RequestedTimestampTooNew', index=6, number=104,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_CRCMismatch', index=7, number=105,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedSteam', index=8, number=106,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ECustomGameInstallStatus_FailedCanceled', index=9, number=107,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=9610,
  serialized_end=10098,
)
_sym_db.RegisterEnumDescriptor(_ECUSTOMGAMEINSTALLSTATUS)

ECustomGameInstallStatus = enum_type_wrapper.EnumTypeWrapper(_ECUSTOMGAMEINSTALLSTATUS)
_GC_BANNEDWORDTYPE = _descriptor.EnumDescriptor(
  name='GC_BannedWordType',
  full_name='GC_BannedWordType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GC_BANNED_WORD_DISABLE_WORD', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GC_BANNED_WORD_ENABLE_WORD', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=10100,
  serialized_end=10184,
)
_sym_db.RegisterEnumDescriptor(_GC_BANNEDWORDTYPE)

GC_BannedWordType = enum_type_wrapper.EnumTypeWrapper(_GC_BANNEDWORDTYPE)
k_EMsgGCSystemMessage = 4001
k_EMsgGCReplicateConVars = 4002
k_EMsgGCConVarUpdated = 4003
k_EMsgGCInviteToParty = 4501
k_EMsgGCInvitationCreated = 4502
k_EMsgGCPartyInviteResponse = 4503
k_EMsgGCKickFromParty = 4504
k_EMsgGCLeaveParty = 4505
k_EMsgGCServerAvailable = 4506
k_EMsgGCClientConnectToServer = 4507
k_EMsgGCGameServerInfo = 4508
k_EMsgGCError = 4509
k_EMsgGCLANServerAvailable = 4511
k_EMsgGCInviteToLobby = 4512
k_EMsgGCLobbyInviteResponse = 4513
k_EProtoObjectPartyInvite = 1001
k_EProtoObjectLobbyInvite = 1002
k_ECustomGameInstallStatus_Unknown = 0
k_ECustomGameInstallStatus_Ready = 1
k_ECustomGameInstallStatus_Busy = 2
k_ECustomGameInstallStatus_FailedGeneric = 101
k_ECustomGameInstallStatus_FailedInternalError = 102
k_ECustomGameInstallStatus_RequestedTimestampTooOld = 103
k_ECustomGameInstallStatus_RequestedTimestampTooNew = 104
k_ECustomGameInstallStatus_CRCMismatch = 105
k_ECustomGameInstallStatus_FailedSteam = 106
k_ECustomGameInstallStatus_FailedCanceled = 107
GC_BANNED_WORD_DISABLE_WORD = 0
GC_BANNED_WORD_ENABLE_WORD = 1


_CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS = _descriptor.EnumDescriptor(
  name='EExtractGems',
  full_name='CMsgExtractGemsResponse.EExtractGems',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_ToolIsInvalid', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_ItemIsInvalid', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_ToolCannotRemoveGem', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ExtractGems_Failed_FailedToRemoveGem', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7410,
  serialized_end=7623,
)
_sym_db.RegisterEnumDescriptor(_CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS)

_CMSGADDSOCKETRESPONSE_EADDSOCKET = _descriptor.EnumDescriptor(
  name='EAddSocket',
  full_name='CMsgAddSocketResponse.EAddSocket',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Failed_ToolIsInvalid', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Failed_ItemCannotBeSocketed', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddSocket_Failed_FailedToAddSocket', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=7853,
  serialized_end=8017,
)
_sym_db.RegisterEnumDescriptor(_CMSGADDSOCKETRESPONSE_EADDSOCKET)

_CMSGADDITEMTOSOCKETRESPONSE_EADDGEM = _descriptor.EnumDescriptor(
  name='EAddGem',
  full_name='CMsgAddItemToSocketResponse.EAddGem',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_GemIsInvalid', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_ItemIsInvalid', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_FailedToAddGem', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_InvalidGemTypeForSocket', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_InvalidGemTypeForHero', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_InvalidGemTypeForSlot', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_AddGem_Failed_SocketContainsUnremovableGem', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8345,
  serialized_end=8664,
)
_sym_db.RegisterEnumDescriptor(_CMSGADDITEMTOSOCKETRESPONSE_EADDGEM)

_CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM = _descriptor.EnumDescriptor(
  name='EResetGem',
  full_name='CMsgResetStrangeGemCountResponse.EResetGem',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Succeeded', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_FailedToResetGem', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_ItemIsInvalid', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_InvalidSocketId', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ResetGem_Failed_SocketCannotBeReset', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8861,
  serialized_end=9057,
)
_sym_db.RegisterEnumDescriptor(_CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM)


_CGCSTOREPURCHASEINIT_LINEITEM = _descriptor.Descriptor(
  name='CGCStorePurchaseInit_LineItem',
  full_name='CGCStorePurchaseInit_LineItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_id', full_name='CGCStorePurchaseInit_LineItem.item_def_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CGCStorePurchaseInit_LineItem.quantity', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cost_in_local_currency', full_name='CGCStorePurchaseInit_LineItem.cost_in_local_currency', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='purchase_type', full_name='CGCStorePurchaseInit_LineItem.purchase_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source_reference_id', full_name='CGCStorePurchaseInit_LineItem.source_reference_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=201,
)


_CMSGGCSTOREPURCHASEINIT = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseInit',
  full_name='CMsgGCStorePurchaseInit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='CMsgGCStorePurchaseInit.country', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgGCStorePurchaseInit.language', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgGCStorePurchaseInit.currency', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line_items', full_name='CMsgGCStorePurchaseInit.line_items', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=334,
)


_CMSGGCSTOREPURCHASEINITRESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseInitResponse',
  full_name='CMsgGCStorePurchaseInitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCStorePurchaseInitResponse.result', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCStorePurchaseInitResponse.txn_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=401,
)


_CMSGSYSTEMBROADCAST = _descriptor.Descriptor(
  name='CMsgSystemBroadcast',
  full_name='CMsgSystemBroadcast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgSystemBroadcast.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=441,
)


_CMSGCLIENTPINGDATA = _descriptor.Descriptor(
  name='CMsgClientPingData',
  full_name='CMsgClientPingData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='relay_codes', full_name='CMsgClientPingData.relay_codes', index=0,
      number=4, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='relay_pings', full_name='CMsgClientPingData.relay_pings', index=1,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='region_codes', full_name='CMsgClientPingData.region_codes', index=2,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='region_pings', full_name='CMsgClientPingData.region_pings', index=3,
      number=9, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='region_ping_failed_bitmask', full_name='CMsgClientPingData.region_ping_failed_bitmask', index=4,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=602,
)


_CMSGINVITETOPARTY = _descriptor.Descriptor(
  name='CMsgInviteToParty',
  full_name='CMsgInviteToParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgInviteToParty.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgInviteToParty.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='team_id', full_name='CMsgInviteToParty.team_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as_coach', full_name='CMsgInviteToParty.as_coach', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='CMsgInviteToParty.ping_data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=741,
)


_CMSGINVITETOLOBBY = _descriptor.Descriptor(
  name='CMsgInviteToLobby',
  full_name='CMsgInviteToLobby',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgInviteToLobby.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgInviteToLobby.client_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=804,
)


_CMSGINVITATIONCREATED = _descriptor.Descriptor(
  name='CMsgInvitationCreated',
  full_name='CMsgInvitationCreated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CMsgInvitationCreated.group_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgInvitationCreated.steam_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_offline', full_name='CMsgInvitationCreated.user_offline', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=806,
  serialized_end=887,
)


_CMSGPARTYINVITERESPONSE = _descriptor.Descriptor(
  name='CMsgPartyInviteResponse',
  full_name='CMsgPartyInviteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgPartyInviteResponse.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accept', full_name='CMsgPartyInviteResponse.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgPartyInviteResponse.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ping_data', full_name='CMsgPartyInviteResponse.ping_data', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=889,
  serialized_end=1012,
)


_CMSGLOBBYINVITERESPONSE = _descriptor.Descriptor(
  name='CMsgLobbyInviteResponse',
  full_name='CMsgLobbyInviteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgLobbyInviteResponse.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='accept', full_name='CMsgLobbyInviteResponse.accept', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgLobbyInviteResponse.client_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_crc', full_name='CMsgLobbyInviteResponse.custom_game_crc', index=3,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_game_timestamp', full_name='CMsgLobbyInviteResponse.custom_game_timestamp', index=4,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1154,
)


_CMSGKICKFROMPARTY = _descriptor.Descriptor(
  name='CMsgKickFromParty',
  full_name='CMsgKickFromParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CMsgKickFromParty.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1193,
)


_CMSGLEAVEPARTY = _descriptor.Descriptor(
  name='CMsgLeaveParty',
  full_name='CMsgLeaveParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1195,
  serialized_end=1211,
)


_CMSGCUSTOMGAMEINSTALLSTATUS = _descriptor.Descriptor(
  name='CMsgCustomGameInstallStatus',
  full_name='CMsgCustomGameInstallStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='CMsgCustomGameInstallStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgCustomGameInstallStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='latest_timestamp_from_steam', full_name='CMsgCustomGameInstallStatus.latest_timestamp_from_steam', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1214,
  serialized_end=1376,
)


_CMSGSERVERAVAILABLE = _descriptor.Descriptor(
  name='CMsgServerAvailable',
  full_name='CMsgServerAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_game_install_status', full_name='CMsgServerAvailable.custom_game_install_status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1378,
  serialized_end=1465,
)


_CMSGLANSERVERAVAILABLE = _descriptor.Descriptor(
  name='CMsgLANServerAvailable',
  full_name='CMsgLANServerAvailable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lobby_id', full_name='CMsgLANServerAvailable.lobby_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1509,
)


_CSOECONGAMEACCOUNTCLIENT = _descriptor.Descriptor(
  name='CSOEconGameAccountClient',
  full_name='CSOEconGameAccountClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='additional_backpack_slots', full_name='CSOEconGameAccountClient.additional_backpack_slots', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trial_account', full_name='CSOEconGameAccountClient.trial_account', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eligible_for_online_play', full_name='CSOEconGameAccountClient.eligible_for_online_play', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='need_to_choose_most_helpful_friend', full_name='CSOEconGameAccountClient.need_to_choose_most_helpful_friend', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_coaches_list', full_name='CSOEconGameAccountClient.in_coaches_list', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trade_ban_expiration', full_name='CSOEconGameAccountClient.trade_ban_expiration', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duel_ban_expiration', full_name='CSOEconGameAccountClient.duel_ban_expiration', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='made_first_purchase', full_name='CSOEconGameAccountClient.made_first_purchase', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1810,
)


_CSOITEMCRITERIACONDITION = _descriptor.Descriptor(
  name='CSOItemCriteriaCondition',
  full_name='CSOItemCriteriaCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='CSOItemCriteriaCondition.op', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='field', full_name='CSOItemCriteriaCondition.field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='required', full_name='CSOItemCriteriaCondition.required', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='CSOItemCriteriaCondition.float_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='CSOItemCriteriaCondition.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1812,
  serialized_end=1926,
)


_CSOITEMCRITERIA = _descriptor.Descriptor(
  name='CSOItemCriteria',
  full_name='CSOItemCriteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_level', full_name='CSOItemCriteria.item_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_quality', full_name='CSOItemCriteria.item_quality', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_level_set', full_name='CSOItemCriteria.item_level_set', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_quality_set', full_name='CSOItemCriteria.item_quality_set', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_inventory', full_name='CSOItemCriteria.initial_inventory', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='initial_quantity', full_name='CSOItemCriteria.initial_quantity', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ignore_enabled_flag', full_name='CSOItemCriteria.ignore_enabled_flag', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='CSOItemCriteria.conditions', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='recent_only', full_name='CSOItemCriteria.recent_only', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1929,
  serialized_end=2188,
)


_CSOITEMRECIPE = _descriptor.Descriptor(
  name='CSOItemRecipe',
  full_name='CSOItemRecipe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOItemRecipe.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CSOItemRecipe.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='n_a', full_name='CSOItemRecipe.n_a', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc_inputs', full_name='CSOItemRecipe.desc_inputs', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc_outputs', full_name='CSOItemRecipe.desc_outputs', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='di_a', full_name='CSOItemRecipe.di_a', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='di_b', full_name='CSOItemRecipe.di_b', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='di_c', full_name='CSOItemRecipe.di_c', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_a', full_name='CSOItemRecipe.do_a', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_b', full_name='CSOItemRecipe.do_b', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='do_c', full_name='CSOItemRecipe.do_c', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requires_all_same_class', full_name='CSOItemRecipe.requires_all_same_class', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requires_all_same_slot', full_name='CSOItemRecipe.requires_all_same_slot', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_usage_for_output', full_name='CSOItemRecipe.class_usage_for_output', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slot_usage_for_output', full_name='CSOItemRecipe.slot_usage_for_output', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='set_for_output', full_name='CSOItemRecipe.set_for_output', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_items_criteria', full_name='CSOItemRecipe.input_items_criteria', index=16,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='output_items_criteria', full_name='CSOItemRecipe.output_items_criteria', index=17,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_item_dupe_counts', full_name='CSOItemRecipe.input_item_dupe_counts', index=18,
      number=22, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2191,
  serialized_end=2660,
)


_CMSGAPPLYSTRANGEPART = _descriptor.Descriptor(
  name='CMsgApplyStrangePart',
  full_name='CMsgApplyStrangePart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strange_part_item_id', full_name='CMsgApplyStrangePart.strange_part_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgApplyStrangePart.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2736,
)


_CMSGAPPLYPENNANTUPGRADE = _descriptor.Descriptor(
  name='CMsgApplyPennantUpgrade',
  full_name='CMsgApplyPennantUpgrade',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_item_id', full_name='CMsgApplyPennantUpgrade.upgrade_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pennant_item_id', full_name='CMsgApplyPennantUpgrade.pennant_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2738,
  serialized_end=2813,
)


_CMSGAPPLYEGGESSENCE = _descriptor.Descriptor(
  name='CMsgApplyEggEssence',
  full_name='CMsgApplyEggEssence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='essence_item_id', full_name='CMsgApplyEggEssence.essence_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='egg_item_id', full_name='CMsgApplyEggEssence.egg_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2815,
  serialized_end=2882,
)


_CSOECONITEMATTRIBUTE = _descriptor.Descriptor(
  name='CSOEconItemAttribute',
  full_name='CSOEconItemAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItemAttribute.def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CSOEconItemAttribute.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value_bytes', full_name='CSOEconItemAttribute.value_bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2884,
  serialized_end=2961,
)


_CSOECONITEMEQUIPPED = _descriptor.Descriptor(
  name='CSOEconItemEquipped',
  full_name='CSOEconItemEquipped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_class', full_name='CSOEconItemEquipped.new_class', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_slot', full_name='CSOEconItemEquipped.new_slot', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2963,
  serialized_end=3021,
)


_CSOECONITEM = _descriptor.Descriptor(
  name='CSOEconItem',
  full_name='CSOEconItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CSOEconItem.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItem.account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='CSOEconItem.inventory', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItem.def_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='CSOEconItem.quantity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='CSOEconItem.level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality', full_name='CSOEconItem.quality', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='CSOEconItem.flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CSOEconItem.origin', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attribute', full_name='CSOEconItem.attribute', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interior_item', full_name='CSOEconItem.interior_item', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_use', full_name='CSOEconItem.in_use', index=11,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='style', full_name='CSOEconItem.style', index=12,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_id', full_name='CSOEconItem.original_id', index=13,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='equipped_state', full_name='CSOEconItem.equipped_state', index=14,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3024,
  serialized_end=3393,
)


_CMSGSORTITEMS = _descriptor.Descriptor(
  name='CMsgSortItems',
  full_name='CMsgSortItems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sort_type', full_name='CMsgSortItems.sort_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3395,
  serialized_end=3429,
)


_CSOECONCLAIMCODE = _descriptor.Descriptor(
  name='CSOEconClaimCode',
  full_name='CSOEconClaimCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconClaimCode.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='CSOEconClaimCode.code_type', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_acquired', full_name='CSOEconClaimCode.time_acquired', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code', full_name='CSOEconClaimCode.code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3431,
  serialized_end=3525,
)


_CMSGSTOREGETUSERDATA = _descriptor.Descriptor(
  name='CMsgStoreGetUserData',
  full_name='CMsgStoreGetUserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='price_sheet_version', full_name='CMsgStoreGetUserData.price_sheet_version', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=3578,
)


_CMSGSTOREGETUSERDATARESPONSE = _descriptor.Descriptor(
  name='CMsgStoreGetUserDataResponse',
  full_name='CMsgStoreGetUserDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgStoreGetUserDataResponse.result', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CMsgStoreGetUserDataResponse.currency', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country', full_name='CMsgStoreGetUserDataResponse.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_sheet_version', full_name='CMsgStoreGetUserDataResponse.price_sheet_version', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='experiment_data', full_name='CMsgStoreGetUserDataResponse.experiment_data', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='featured_item_idx', full_name='CMsgStoreGetUserDataResponse.featured_item_idx', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='show_hat_descriptions', full_name='CMsgStoreGetUserDataResponse.show_hat_descriptions', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_sheet', full_name='CMsgStoreGetUserDataResponse.price_sheet', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='default_item_sort', full_name='CMsgStoreGetUserDataResponse.default_item_sort', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='popular_items', full_name='CMsgStoreGetUserDataResponse.popular_items', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3581,
  serialized_end=3857,
)


_CMSGUPDATEITEMSCHEMA = _descriptor.Descriptor(
  name='CMsgUpdateItemSchema',
  full_name='CMsgUpdateItemSchema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items_game', full_name='CMsgUpdateItemSchema.items_game', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_schema_version', full_name='CMsgUpdateItemSchema.item_schema_version', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='items_game_url', full_name='CMsgUpdateItemSchema.items_game_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3859,
  serialized_end=3954,
)


_CMSGGCERROR = _descriptor.Descriptor(
  name='CMsgGCError',
  full_name='CMsgGCError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_text', full_name='CMsgGCError.error_text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3956,
  serialized_end=3989,
)


_CMSGREQUESTINVENTORYREFRESH = _descriptor.Descriptor(
  name='CMsgRequestInventoryRefresh',
  full_name='CMsgRequestInventoryRefresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3991,
  serialized_end=4020,
)


_CMSGCONVARVALUE = _descriptor.Descriptor(
  name='CMsgConVarValue',
  full_name='CMsgConVarValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgConVarValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgConVarValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4022,
  serialized_end=4068,
)


_CMSGREPLICATECONVARS = _descriptor.Descriptor(
  name='CMsgReplicateConVars',
  full_name='CMsgReplicateConVars',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='convars', full_name='CMsgReplicateConVars.convars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4070,
  serialized_end=4127,
)


_CMSGCONSUMABLEEXHAUSTED = _descriptor.Descriptor(
  name='CMsgConsumableExhausted',
  full_name='CMsgConsumableExhausted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_id', full_name='CMsgConsumableExhausted.item_def_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4129,
  serialized_end=4175,
)


_CMSGITEMACKNOWLEDGED = _descriptor.Descriptor(
  name='CMsgItemAcknowledged',
  full_name='CMsgItemAcknowledged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgItemAcknowledged.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inventory', full_name='CMsgItemAcknowledged.inventory', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CMsgItemAcknowledged.def_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quality', full_name='CMsgItemAcknowledged.quality', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rarity', full_name='CMsgItemAcknowledged.rarity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='CMsgItemAcknowledged.origin', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4178,
  serialized_end=4307,
)


_CMSGSETITEMPOSITIONS_ITEMPOSITION = _descriptor.Descriptor(
  name='ItemPosition',
  full_name='CMsgSetItemPositions.ItemPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgSetItemPositions.ItemPosition.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='CMsgSetItemPositions.ItemPosition.position', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4394,
  serialized_end=4443,
)

_CMSGSETITEMPOSITIONS = _descriptor.Descriptor(
  name='CMsgSetItemPositions',
  full_name='CMsgSetItemPositions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_positions', full_name='CMsgSetItemPositions.item_positions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSETITEMPOSITIONS_ITEMPOSITION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4310,
  serialized_end=4443,
)


_CMSGGCNAMEITEMNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCNameItemNotification',
  full_name='CMsgGCNameItemNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_steamid', full_name='CMsgGCNameItemNotification.player_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CMsgGCNameItemNotification.item_def_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_name_custom', full_name='CMsgGCNameItemNotification.item_name_custom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4445,
  serialized_end=4547,
)


_CMSGGCCLIENTDISPLAYNOTIFICATION = _descriptor.Descriptor(
  name='CMsgGCClientDisplayNotification',
  full_name='CMsgGCClientDisplayNotification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notification_title_localization_key', full_name='CMsgGCClientDisplayNotification.notification_title_localization_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='notification_body_localization_key', full_name='CMsgGCClientDisplayNotification.notification_body_localization_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body_substring_keys', full_name='CMsgGCClientDisplayNotification.body_substring_keys', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body_substring_values', full_name='CMsgGCClientDisplayNotification.body_substring_values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4550,
  serialized_end=4732,
)


_CMSGGCSHOWITEMSPICKEDUP = _descriptor.Descriptor(
  name='CMsgGCShowItemsPickedUp',
  full_name='CMsgGCShowItemsPickedUp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_steamid', full_name='CMsgGCShowItemsPickedUp.player_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4734,
  serialized_end=4783,
)


_CMSGGCINCREMENTKILLCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCIncrementKillCountResponse',
  full_name='CMsgGCIncrementKillCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='killer_account_id', full_name='CMsgGCIncrementKillCountResponse.killer_account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='num_kills', full_name='CMsgGCIncrementKillCountResponse.num_kills', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_def', full_name='CMsgGCIncrementKillCountResponse.item_def', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level_type', full_name='CMsgGCIncrementKillCountResponse.level_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4785,
  serialized_end=4909,
)


_CSOECONITEMDROPRATEBONUS = _descriptor.Descriptor(
  name='CSOEconItemDropRateBonus',
  full_name='CSOEconItemDropRateBonus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemDropRateBonus.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='expiration_date', full_name='CSOEconItemDropRateBonus.expiration_date', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bonus', full_name='CSOEconItemDropRateBonus.bonus', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='bonus_count', full_name='CSOEconItemDropRateBonus.bonus_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CSOEconItemDropRateBonus.item_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItemDropRateBonus.def_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_left', full_name='CSOEconItemDropRateBonus.seconds_left', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='booster_type', full_name='CSOEconItemDropRateBonus.booster_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4912,
  serialized_end=5117,
)


_CSOECONITEMLEAGUEVIEWPASS = _descriptor.Descriptor(
  name='CSOEconItemLeagueViewPass',
  full_name='CSOEconItemLeagueViewPass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemLeagueViewPass.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CSOEconItemLeagueViewPass.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))),
    _descriptor.FieldDescriptor(
      name='itemindex', full_name='CSOEconItemLeagueViewPass.itemindex', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grant_reason', full_name='CSOEconItemLeagueViewPass.grant_reason', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5119,
  serialized_end=5238,
)


_CSOECONITEMEVENTTICKET = _descriptor.Descriptor(
  name='CSOEconItemEventTicket',
  full_name='CSOEconItemEventTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemEventTicket.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='event_id', full_name='CSOEconItemEventTicket.event_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CSOEconItemEventTicket.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5240,
  serialized_end=5319,
)


_CSOECONITEMTOURNAMENTPASSPORT = _descriptor.Descriptor(
  name='CSOEconItemTournamentPassport',
  full_name='CSOEconItemTournamentPassport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CSOEconItemTournamentPassport.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='league_id', full_name='CSOEconItemTournamentPassport.league_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CSOEconItemTournamentPassport.item_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_purchaser_id', full_name='CSOEconItemTournamentPassport.original_purchaser_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='passports_bought', full_name='CSOEconItemTournamentPassport.passports_bought', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='CSOEconItemTournamentPassport.version', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='def_index', full_name='CSOEconItemTournamentPassport.def_index', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reward_flags', full_name='CSOEconItemTournamentPassport.reward_flags', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5322,
  serialized_end=5524,
)


_CMSGGCSTOREPURCHASECANCEL = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseCancel',
  full_name='CMsgGCStorePurchaseCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCStorePurchaseCancel.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5526,
  serialized_end=5569,
)


_CMSGGCSTOREPURCHASECANCELRESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseCancelResponse',
  full_name='CMsgGCStorePurchaseCancelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCStorePurchaseCancelResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5571,
  serialized_end=5622,
)


_CMSGGCSTOREPURCHASEFINALIZE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseFinalize',
  full_name='CMsgGCStorePurchaseFinalize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_id', full_name='CMsgGCStorePurchaseFinalize.txn_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5624,
  serialized_end=5669,
)


_CMSGGCSTOREPURCHASEFINALIZERESPONSE = _descriptor.Descriptor(
  name='CMsgGCStorePurchaseFinalizeResponse',
  full_name='CMsgGCStorePurchaseFinalizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgGCStorePurchaseFinalizeResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_ids', full_name='CMsgGCStorePurchaseFinalizeResponse.item_ids', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5671,
  serialized_end=5742,
)


_CMSGGCBANNEDWORDLISTREQUEST = _descriptor.Descriptor(
  name='CMsgGCBannedWordListRequest',
  full_name='CMsgGCBannedWordListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ban_list_group_id', full_name='CMsgGCBannedWordListRequest.ban_list_group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word_id', full_name='CMsgGCBannedWordListRequest.word_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5744,
  serialized_end=5817,
)


_CMSGGCBANNEDWORD = _descriptor.Descriptor(
  name='CMsgGCBannedWord',
  full_name='CMsgGCBannedWord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word_id', full_name='CMsgGCBannedWord.word_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word_type', full_name='CMsgGCBannedWord.word_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word', full_name='CMsgGCBannedWord.word', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5819,
  serialized_end=5936,
)


_CMSGGCBANNEDWORDLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgGCBannedWordListResponse',
  full_name='CMsgGCBannedWordListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ban_list_group_id', full_name='CMsgGCBannedWordListResponse.ban_list_group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='word_list', full_name='CMsgGCBannedWordListResponse.word_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5938,
  serialized_end=6033,
)


_CMSGGCTOGCBANNEDWORDLISTBROADCAST = _descriptor.Descriptor(
  name='CMsgGCToGCBannedWordListBroadcast',
  full_name='CMsgGCToGCBannedWordListBroadcast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast', full_name='CMsgGCToGCBannedWordListBroadcast.broadcast', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6035,
  serialized_end=6120,
)


_CMSGGCTOGCBANNEDWORDLISTUPDATED = _descriptor.Descriptor(
  name='CMsgGCToGCBannedWordListUpdated',
  full_name='CMsgGCToGCBannedWordListUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_id', full_name='CMsgGCToGCBannedWordListUpdated.group_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6122,
  serialized_end=6173,
)


_CMSGGCTOGCDIRTYSDOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCDirtySDOCache',
  full_name='CMsgGCToGCDirtySDOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdo_type', full_name='CMsgGCToGCDirtySDOCache.sdo_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key_uint64', full_name='CMsgGCToGCDirtySDOCache.key_uint64', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6175,
  serialized_end=6238,
)


_CMSGGCTOGCDIRTYMULTIPLESDOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCDirtyMultipleSDOCache',
  full_name='CMsgGCToGCDirtyMultipleSDOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sdo_type', full_name='CMsgGCToGCDirtyMultipleSDOCache.sdo_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key_uint64', full_name='CMsgGCToGCDirtyMultipleSDOCache.key_uint64', index=1,
      number=2, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6240,
  serialized_end=6311,
)


_CMSGGCTOGCAPPLYLOCALIZATIONDIFF = _descriptor.Descriptor(
  name='CMsgGCToGCApplyLocalizationDiff',
  full_name='CMsgGCToGCApplyLocalizationDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CMsgGCToGCApplyLocalizationDiff.language', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packed_diff', full_name='CMsgGCToGCApplyLocalizationDiff.packed_diff', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6313,
  serialized_end=6385,
)


_CMSGGCTOGCAPPLYLOCALIZATIONDIFFRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCApplyLocalizationDiffResponse',
  full_name='CMsgGCToGCApplyLocalizationDiffResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CMsgGCToGCApplyLocalizationDiffResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6387,
  serialized_end=6445,
)


_CMSGGCCOLLECTITEM = _descriptor.Descriptor(
  name='CMsgGCCollectItem',
  full_name='CMsgGCCollectItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_item_id', full_name='CMsgGCCollectItem.collection_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject_item_id', full_name='CMsgGCCollectItem.subject_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6447,
  serialized_end=6519,
)


_CMSGSDONOMEMCACHED = _descriptor.Descriptor(
  name='CMsgSDONoMemcached',
  full_name='CMsgSDONoMemcached',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6521,
  serialized_end=6541,
)


_CMSGGCTOGCUPDATESQLKEYVALUE = _descriptor.Descriptor(
  name='CMsgGCToGCUpdateSQLKeyValue',
  full_name='CMsgGCToGCUpdateSQLKeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_name', full_name='CMsgGCToGCUpdateSQLKeyValue.key_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6543,
  serialized_end=6590,
)


_CMSGGCSERVERVERSIONUPDATED = _descriptor.Descriptor(
  name='CMsgGCServerVersionUpdated',
  full_name='CMsgGCServerVersionUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_version', full_name='CMsgGCServerVersionUpdated.server_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6592,
  serialized_end=6644,
)


_CMSGGCCLIENTVERSIONUPDATED = _descriptor.Descriptor(
  name='CMsgGCClientVersionUpdated',
  full_name='CMsgGCClientVersionUpdated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_version', full_name='CMsgGCClientVersionUpdated.client_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6646,
  serialized_end=6698,
)


_CMSGGCTOGCWEBAPIACCOUNTCHANGED = _descriptor.Descriptor(
  name='CMsgGCToGCWebAPIAccountChanged',
  full_name='CMsgGCToGCWebAPIAccountChanged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6700,
  serialized_end=6732,
)


_CMSGRECIPECOMPONENT = _descriptor.Descriptor(
  name='CMsgRecipeComponent',
  full_name='CMsgRecipeComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject_item_id', full_name='CMsgRecipeComponent.subject_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attribute_index', full_name='CMsgRecipeComponent.attribute_index', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6734,
  serialized_end=6805,
)


_CMSGFULFILLDYNAMICRECIPECOMPONENT = _descriptor.Descriptor(
  name='CMsgFulfillDynamicRecipeComponent',
  full_name='CMsgFulfillDynamicRecipeComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='CMsgFulfillDynamicRecipeComponent.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='consumption_components', full_name='CMsgFulfillDynamicRecipeComponent.consumption_components', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6807,
  serialized_end=6918,
)


_CMSGGCCLIENTMARKETDATAREQUEST = _descriptor.Descriptor(
  name='CMsgGCClientMarketDataRequest',
  full_name='CMsgGCClientMarketDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_currency', full_name='CMsgGCClientMarketDataRequest.user_currency', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6920,
  serialized_end=6974,
)


_CMSGGCCLIENTMARKETDATAENTRY = _descriptor.Descriptor(
  name='CMsgGCClientMarketDataEntry',
  full_name='CMsgGCClientMarketDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_def_index', full_name='CMsgGCClientMarketDataEntry.item_def_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_quality', full_name='CMsgGCClientMarketDataEntry.item_quality', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_sell_listings', full_name='CMsgGCClientMarketDataEntry.item_sell_listings', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price_in_local_currency', full_name='CMsgGCClientMarketDataEntry.price_in_local_currency', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6977,
  serialized_end=7113,
)


_CMSGGCCLIENTMARKETDATA = _descriptor.Descriptor(
  name='CMsgGCClientMarketData',
  full_name='CMsgGCClientMarketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgGCClientMarketData.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7115,
  serialized_end=7186,
)


_CMSGEXTRACTGEMS = _descriptor.Descriptor(
  name='CMsgExtractGems',
  full_name='CMsgExtractGems',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='CMsgExtractGems.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgExtractGems.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_socket_id', full_name='CMsgExtractGems.item_socket_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=65535,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7188,
  serialized_end=7280,
)


_CMSGEXTRACTGEMSRESPONSE = _descriptor.Descriptor(
  name='CMsgExtractGemsResponse',
  full_name='CMsgExtractGemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgExtractGemsResponse.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgExtractGemsResponse.response', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7283,
  serialized_end=7623,
)


_CMSGADDSOCKET = _descriptor.Descriptor(
  name='CMsgAddSocket',
  full_name='CMsgAddSocket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool_item_id', full_name='CMsgAddSocket.tool_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgAddSocket.item_item_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unusual', full_name='CMsgAddSocket.unusual', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7625,
  serialized_end=7701,
)


_CMSGADDSOCKETRESPONSE = _descriptor.Descriptor(
  name='CMsgAddSocketResponse',
  full_name='CMsgAddSocketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_id', full_name='CMsgAddSocketResponse.item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_socket_index', full_name='CMsgAddSocketResponse.updated_socket_index', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgAddSocketResponse.response', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGADDSOCKETRESPONSE_EADDSOCKET,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7704,
  serialized_end=8017,
)


_CMSGADDITEMTOSOCKETDATA = _descriptor.Descriptor(
  name='CMsgAddItemToSocketData',
  full_name='CMsgAddItemToSocketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gem_item_id', full_name='CMsgAddItemToSocketData.gem_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='socket_index', full_name='CMsgAddItemToSocketData.socket_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8019,
  serialized_end=8087,
)


_CMSGADDITEMTOSOCKET = _descriptor.Descriptor(
  name='CMsgAddItemToSocket',
  full_name='CMsgAddItemToSocket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgAddItemToSocket.item_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gems_to_socket', full_name='CMsgAddItemToSocket.gems_to_socket', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8089,
  serialized_end=8182,
)


_CMSGADDITEMTOSOCKETRESPONSE = _descriptor.Descriptor(
  name='CMsgAddItemToSocketResponse',
  full_name='CMsgAddItemToSocketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgAddItemToSocketResponse.item_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updated_socket_index', full_name='CMsgAddItemToSocketResponse.updated_socket_index', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgAddItemToSocketResponse.response', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGADDITEMTOSOCKETRESPONSE_EADDGEM,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8185,
  serialized_end=8664,
)


_CMSGRESETSTRANGEGEMCOUNT = _descriptor.Descriptor(
  name='CMsgResetStrangeGemCount',
  full_name='CMsgResetStrangeGemCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item_item_id', full_name='CMsgResetStrangeGemCount.item_item_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='socket_index', full_name='CMsgResetStrangeGemCount.socket_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8666,
  serialized_end=8736,
)


_CMSGRESETSTRANGEGEMCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgResetStrangeGemCountResponse',
  full_name='CMsgResetStrangeGemCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CMsgResetStrangeGemCountResponse.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8739,
  serialized_end=9057,
)

_CMSGGCSTOREPURCHASEINIT.fields_by_name['line_items'].message_type = _CGCSTOREPURCHASEINIT_LINEITEM
_CMSGINVITETOPARTY.fields_by_name['ping_data'].message_type = _CMSGCLIENTPINGDATA
_CMSGPARTYINVITERESPONSE.fields_by_name['ping_data'].message_type = _CMSGCLIENTPINGDATA
_CMSGCUSTOMGAMEINSTALLSTATUS.fields_by_name['status'].enum_type = _ECUSTOMGAMEINSTALLSTATUS
_CMSGSERVERAVAILABLE.fields_by_name['custom_game_install_status'].message_type = _CMSGCUSTOMGAMEINSTALLSTATUS
_CSOITEMCRITERIA.fields_by_name['conditions'].message_type = _CSOITEMCRITERIACONDITION
_CSOITEMRECIPE.fields_by_name['input_items_criteria'].message_type = _CSOITEMCRITERIA
_CSOITEMRECIPE.fields_by_name['output_items_criteria'].message_type = _CSOITEMCRITERIA
_CSOECONITEM.fields_by_name['attribute'].message_type = _CSOECONITEMATTRIBUTE
_CSOECONITEM.fields_by_name['interior_item'].message_type = _CSOECONITEM
_CSOECONITEM.fields_by_name['equipped_state'].message_type = _CSOECONITEMEQUIPPED
_CMSGREPLICATECONVARS.fields_by_name['convars'].message_type = _CMSGCONVARVALUE
_CMSGSETITEMPOSITIONS_ITEMPOSITION.containing_type = _CMSGSETITEMPOSITIONS
_CMSGSETITEMPOSITIONS.fields_by_name['item_positions'].message_type = _CMSGSETITEMPOSITIONS_ITEMPOSITION
_CMSGGCBANNEDWORD.fields_by_name['word_type'].enum_type = _GC_BANNEDWORDTYPE
_CMSGGCBANNEDWORDLISTRESPONSE.fields_by_name['word_list'].message_type = _CMSGGCBANNEDWORD
_CMSGGCTOGCBANNEDWORDLISTBROADCAST.fields_by_name['broadcast'].message_type = _CMSGGCBANNEDWORDLISTRESPONSE
_CMSGFULFILLDYNAMICRECIPECOMPONENT.fields_by_name['consumption_components'].message_type = _CMSGRECIPECOMPONENT
_CMSGGCCLIENTMARKETDATA.fields_by_name['entries'].message_type = _CMSGGCCLIENTMARKETDATAENTRY
_CMSGEXTRACTGEMSRESPONSE.fields_by_name['response'].enum_type = _CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS
_CMSGEXTRACTGEMSRESPONSE_EEXTRACTGEMS.containing_type = _CMSGEXTRACTGEMSRESPONSE
_CMSGADDSOCKETRESPONSE.fields_by_name['response'].enum_type = _CMSGADDSOCKETRESPONSE_EADDSOCKET
_CMSGADDSOCKETRESPONSE_EADDSOCKET.containing_type = _CMSGADDSOCKETRESPONSE
_CMSGADDITEMTOSOCKET.fields_by_name['gems_to_socket'].message_type = _CMSGADDITEMTOSOCKETDATA
_CMSGADDITEMTOSOCKETRESPONSE.fields_by_name['response'].enum_type = _CMSGADDITEMTOSOCKETRESPONSE_EADDGEM
_CMSGADDITEMTOSOCKETRESPONSE_EADDGEM.containing_type = _CMSGADDITEMTOSOCKETRESPONSE
_CMSGRESETSTRANGEGEMCOUNTRESPONSE.fields_by_name['response'].enum_type = _CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM
_CMSGRESETSTRANGEGEMCOUNTRESPONSE_ERESETGEM.containing_type = _CMSGRESETSTRANGEGEMCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CGCStorePurchaseInit_LineItem'] = _CGCSTOREPURCHASEINIT_LINEITEM
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseInit'] = _CMSGGCSTOREPURCHASEINIT
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseInitResponse'] = _CMSGGCSTOREPURCHASEINITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgSystemBroadcast'] = _CMSGSYSTEMBROADCAST
DESCRIPTOR.message_types_by_name['CMsgClientPingData'] = _CMSGCLIENTPINGDATA
DESCRIPTOR.message_types_by_name['CMsgInviteToParty'] = _CMSGINVITETOPARTY
DESCRIPTOR.message_types_by_name['CMsgInviteToLobby'] = _CMSGINVITETOLOBBY
DESCRIPTOR.message_types_by_name['CMsgInvitationCreated'] = _CMSGINVITATIONCREATED
DESCRIPTOR.message_types_by_name['CMsgPartyInviteResponse'] = _CMSGPARTYINVITERESPONSE
DESCRIPTOR.message_types_by_name['CMsgLobbyInviteResponse'] = _CMSGLOBBYINVITERESPONSE
DESCRIPTOR.message_types_by_name['CMsgKickFromParty'] = _CMSGKICKFROMPARTY
DESCRIPTOR.message_types_by_name['CMsgLeaveParty'] = _CMSGLEAVEPARTY
DESCRIPTOR.message_types_by_name['CMsgCustomGameInstallStatus'] = _CMSGCUSTOMGAMEINSTALLSTATUS
DESCRIPTOR.message_types_by_name['CMsgServerAvailable'] = _CMSGSERVERAVAILABLE
DESCRIPTOR.message_types_by_name['CMsgLANServerAvailable'] = _CMSGLANSERVERAVAILABLE
DESCRIPTOR.message_types_by_name['CSOEconGameAccountClient'] = _CSOECONGAMEACCOUNTCLIENT
DESCRIPTOR.message_types_by_name['CSOItemCriteriaCondition'] = _CSOITEMCRITERIACONDITION
DESCRIPTOR.message_types_by_name['CSOItemCriteria'] = _CSOITEMCRITERIA
DESCRIPTOR.message_types_by_name['CSOItemRecipe'] = _CSOITEMRECIPE
DESCRIPTOR.message_types_by_name['CMsgApplyStrangePart'] = _CMSGAPPLYSTRANGEPART
DESCRIPTOR.message_types_by_name['CMsgApplyPennantUpgrade'] = _CMSGAPPLYPENNANTUPGRADE
DESCRIPTOR.message_types_by_name['CMsgApplyEggEssence'] = _CMSGAPPLYEGGESSENCE
DESCRIPTOR.message_types_by_name['CSOEconItemAttribute'] = _CSOECONITEMATTRIBUTE
DESCRIPTOR.message_types_by_name['CSOEconItemEquipped'] = _CSOECONITEMEQUIPPED
DESCRIPTOR.message_types_by_name['CSOEconItem'] = _CSOECONITEM
DESCRIPTOR.message_types_by_name['CMsgSortItems'] = _CMSGSORTITEMS
DESCRIPTOR.message_types_by_name['CSOEconClaimCode'] = _CSOECONCLAIMCODE
DESCRIPTOR.message_types_by_name['CMsgStoreGetUserData'] = _CMSGSTOREGETUSERDATA
DESCRIPTOR.message_types_by_name['CMsgStoreGetUserDataResponse'] = _CMSGSTOREGETUSERDATARESPONSE
DESCRIPTOR.message_types_by_name['CMsgUpdateItemSchema'] = _CMSGUPDATEITEMSCHEMA
DESCRIPTOR.message_types_by_name['CMsgGCError'] = _CMSGGCERROR
DESCRIPTOR.message_types_by_name['CMsgRequestInventoryRefresh'] = _CMSGREQUESTINVENTORYREFRESH
DESCRIPTOR.message_types_by_name['CMsgConVarValue'] = _CMSGCONVARVALUE
DESCRIPTOR.message_types_by_name['CMsgReplicateConVars'] = _CMSGREPLICATECONVARS
DESCRIPTOR.message_types_by_name['CMsgConsumableExhausted'] = _CMSGCONSUMABLEEXHAUSTED
DESCRIPTOR.message_types_by_name['CMsgItemAcknowledged'] = _CMSGITEMACKNOWLEDGED
DESCRIPTOR.message_types_by_name['CMsgSetItemPositions'] = _CMSGSETITEMPOSITIONS
DESCRIPTOR.message_types_by_name['CMsgGCNameItemNotification'] = _CMSGGCNAMEITEMNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCClientDisplayNotification'] = _CMSGGCCLIENTDISPLAYNOTIFICATION
DESCRIPTOR.message_types_by_name['CMsgGCShowItemsPickedUp'] = _CMSGGCSHOWITEMSPICKEDUP
DESCRIPTOR.message_types_by_name['CMsgGCIncrementKillCountResponse'] = _CMSGGCINCREMENTKILLCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CSOEconItemDropRateBonus'] = _CSOECONITEMDROPRATEBONUS
DESCRIPTOR.message_types_by_name['CSOEconItemLeagueViewPass'] = _CSOECONITEMLEAGUEVIEWPASS
DESCRIPTOR.message_types_by_name['CSOEconItemEventTicket'] = _CSOECONITEMEVENTTICKET
DESCRIPTOR.message_types_by_name['CSOEconItemTournamentPassport'] = _CSOECONITEMTOURNAMENTPASSPORT
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseCancel'] = _CMSGGCSTOREPURCHASECANCEL
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseCancelResponse'] = _CMSGGCSTOREPURCHASECANCELRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseFinalize'] = _CMSGGCSTOREPURCHASEFINALIZE
DESCRIPTOR.message_types_by_name['CMsgGCStorePurchaseFinalizeResponse'] = _CMSGGCSTOREPURCHASEFINALIZERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCBannedWordListRequest'] = _CMSGGCBANNEDWORDLISTREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCBannedWord'] = _CMSGGCBANNEDWORD
DESCRIPTOR.message_types_by_name['CMsgGCBannedWordListResponse'] = _CMSGGCBANNEDWORDLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCBannedWordListBroadcast'] = _CMSGGCTOGCBANNEDWORDLISTBROADCAST
DESCRIPTOR.message_types_by_name['CMsgGCToGCBannedWordListUpdated'] = _CMSGGCTOGCBANNEDWORDLISTUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCToGCDirtySDOCache'] = _CMSGGCTOGCDIRTYSDOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCDirtyMultipleSDOCache'] = _CMSGGCTOGCDIRTYMULTIPLESDOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCApplyLocalizationDiff'] = _CMSGGCTOGCAPPLYLOCALIZATIONDIFF
DESCRIPTOR.message_types_by_name['CMsgGCToGCApplyLocalizationDiffResponse'] = _CMSGGCTOGCAPPLYLOCALIZATIONDIFFRESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCCollectItem'] = _CMSGGCCOLLECTITEM
DESCRIPTOR.message_types_by_name['CMsgSDONoMemcached'] = _CMSGSDONOMEMCACHED
DESCRIPTOR.message_types_by_name['CMsgGCToGCUpdateSQLKeyValue'] = _CMSGGCTOGCUPDATESQLKEYVALUE
DESCRIPTOR.message_types_by_name['CMsgGCServerVersionUpdated'] = _CMSGGCSERVERVERSIONUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCClientVersionUpdated'] = _CMSGGCCLIENTVERSIONUPDATED
DESCRIPTOR.message_types_by_name['CMsgGCToGCWebAPIAccountChanged'] = _CMSGGCTOGCWEBAPIACCOUNTCHANGED
DESCRIPTOR.message_types_by_name['CMsgRecipeComponent'] = _CMSGRECIPECOMPONENT
DESCRIPTOR.message_types_by_name['CMsgFulfillDynamicRecipeComponent'] = _CMSGFULFILLDYNAMICRECIPECOMPONENT
DESCRIPTOR.message_types_by_name['CMsgGCClientMarketDataRequest'] = _CMSGGCCLIENTMARKETDATAREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCClientMarketDataEntry'] = _CMSGGCCLIENTMARKETDATAENTRY
DESCRIPTOR.message_types_by_name['CMsgGCClientMarketData'] = _CMSGGCCLIENTMARKETDATA
DESCRIPTOR.message_types_by_name['CMsgExtractGems'] = _CMSGEXTRACTGEMS
DESCRIPTOR.message_types_by_name['CMsgExtractGemsResponse'] = _CMSGEXTRACTGEMSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgAddSocket'] = _CMSGADDSOCKET
DESCRIPTOR.message_types_by_name['CMsgAddSocketResponse'] = _CMSGADDSOCKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgAddItemToSocketData'] = _CMSGADDITEMTOSOCKETDATA
DESCRIPTOR.message_types_by_name['CMsgAddItemToSocket'] = _CMSGADDITEMTOSOCKET
DESCRIPTOR.message_types_by_name['CMsgAddItemToSocketResponse'] = _CMSGADDITEMTOSOCKETRESPONSE
DESCRIPTOR.message_types_by_name['CMsgResetStrangeGemCount'] = _CMSGRESETSTRANGEGEMCOUNT
DESCRIPTOR.message_types_by_name['CMsgResetStrangeGemCountResponse'] = _CMSGRESETSTRANGEGEMCOUNTRESPONSE
DESCRIPTOR.enum_types_by_name['EGCBaseMsg'] = _EGCBASEMSG
DESCRIPTOR.enum_types_by_name['EGCBaseProtoObjectTypes'] = _EGCBASEPROTOOBJECTTYPES
DESCRIPTOR.enum_types_by_name['ECustomGameInstallStatus'] = _ECUSTOMGAMEINSTALLSTATUS
DESCRIPTOR.enum_types_by_name['GC_BannedWordType'] = _GC_BANNEDWORDTYPE

CGCStorePurchaseInit_LineItem = _reflection.GeneratedProtocolMessageType('CGCStorePurchaseInit_LineItem', (_message.Message,), dict(
  DESCRIPTOR = _CGCSTOREPURCHASEINIT_LINEITEM,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CGCStorePurchaseInit_LineItem)
  ))
_sym_db.RegisterMessage(CGCStorePurchaseInit_LineItem)

CMsgGCStorePurchaseInit = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseInit', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEINIT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseInit)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseInit)

CMsgGCStorePurchaseInitResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseInitResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEINITRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseInitResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseInitResponse)

CMsgSystemBroadcast = _reflection.GeneratedProtocolMessageType('CMsgSystemBroadcast', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSYSTEMBROADCAST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemBroadcast)
  ))
_sym_db.RegisterMessage(CMsgSystemBroadcast)

CMsgClientPingData = _reflection.GeneratedProtocolMessageType('CMsgClientPingData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTPINGDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientPingData)
  ))
_sym_db.RegisterMessage(CMsgClientPingData)

CMsgInviteToParty = _reflection.GeneratedProtocolMessageType('CMsgInviteToParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITETOPARTY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgInviteToParty)
  ))
_sym_db.RegisterMessage(CMsgInviteToParty)

CMsgInviteToLobby = _reflection.GeneratedProtocolMessageType('CMsgInviteToLobby', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITETOLOBBY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgInviteToLobby)
  ))
_sym_db.RegisterMessage(CMsgInviteToLobby)

CMsgInvitationCreated = _reflection.GeneratedProtocolMessageType('CMsgInvitationCreated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGINVITATIONCREATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgInvitationCreated)
  ))
_sym_db.RegisterMessage(CMsgInvitationCreated)

CMsgPartyInviteResponse = _reflection.GeneratedProtocolMessageType('CMsgPartyInviteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGPARTYINVITERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgPartyInviteResponse)
  ))
_sym_db.RegisterMessage(CMsgPartyInviteResponse)

CMsgLobbyInviteResponse = _reflection.GeneratedProtocolMessageType('CMsgLobbyInviteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLOBBYINVITERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLobbyInviteResponse)
  ))
_sym_db.RegisterMessage(CMsgLobbyInviteResponse)

CMsgKickFromParty = _reflection.GeneratedProtocolMessageType('CMsgKickFromParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGKICKFROMPARTY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgKickFromParty)
  ))
_sym_db.RegisterMessage(CMsgKickFromParty)

CMsgLeaveParty = _reflection.GeneratedProtocolMessageType('CMsgLeaveParty', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLEAVEPARTY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLeaveParty)
  ))
_sym_db.RegisterMessage(CMsgLeaveParty)

CMsgCustomGameInstallStatus = _reflection.GeneratedProtocolMessageType('CMsgCustomGameInstallStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCUSTOMGAMEINSTALLSTATUS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCustomGameInstallStatus)
  ))
_sym_db.RegisterMessage(CMsgCustomGameInstallStatus)

CMsgServerAvailable = _reflection.GeneratedProtocolMessageType('CMsgServerAvailable', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSERVERAVAILABLE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgServerAvailable)
  ))
_sym_db.RegisterMessage(CMsgServerAvailable)

CMsgLANServerAvailable = _reflection.GeneratedProtocolMessageType('CMsgLANServerAvailable', (_message.Message,), dict(
  DESCRIPTOR = _CMSGLANSERVERAVAILABLE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgLANServerAvailable)
  ))
_sym_db.RegisterMessage(CMsgLANServerAvailable)

CSOEconGameAccountClient = _reflection.GeneratedProtocolMessageType('CSOEconGameAccountClient', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONGAMEACCOUNTCLIENT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconGameAccountClient)
  ))
_sym_db.RegisterMessage(CSOEconGameAccountClient)

CSOItemCriteriaCondition = _reflection.GeneratedProtocolMessageType('CSOItemCriteriaCondition', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMCRITERIACONDITION,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOItemCriteriaCondition)
  ))
_sym_db.RegisterMessage(CSOItemCriteriaCondition)

CSOItemCriteria = _reflection.GeneratedProtocolMessageType('CSOItemCriteria', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMCRITERIA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOItemCriteria)
  ))
_sym_db.RegisterMessage(CSOItemCriteria)

CSOItemRecipe = _reflection.GeneratedProtocolMessageType('CSOItemRecipe', (_message.Message,), dict(
  DESCRIPTOR = _CSOITEMRECIPE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOItemRecipe)
  ))
_sym_db.RegisterMessage(CSOItemRecipe)

CMsgApplyStrangePart = _reflection.GeneratedProtocolMessageType('CMsgApplyStrangePart', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYSTRANGEPART,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyStrangePart)
  ))
_sym_db.RegisterMessage(CMsgApplyStrangePart)

CMsgApplyPennantUpgrade = _reflection.GeneratedProtocolMessageType('CMsgApplyPennantUpgrade', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYPENNANTUPGRADE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyPennantUpgrade)
  ))
_sym_db.RegisterMessage(CMsgApplyPennantUpgrade)

CMsgApplyEggEssence = _reflection.GeneratedProtocolMessageType('CMsgApplyEggEssence', (_message.Message,), dict(
  DESCRIPTOR = _CMSGAPPLYEGGESSENCE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgApplyEggEssence)
  ))
_sym_db.RegisterMessage(CMsgApplyEggEssence)

CSOEconItemAttribute = _reflection.GeneratedProtocolMessageType('CSOEconItemAttribute', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMATTRIBUTE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemAttribute)
  ))
_sym_db.RegisterMessage(CSOEconItemAttribute)

CSOEconItemEquipped = _reflection.GeneratedProtocolMessageType('CSOEconItemEquipped', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMEQUIPPED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemEquipped)
  ))
_sym_db.RegisterMessage(CSOEconItemEquipped)

CSOEconItem = _reflection.GeneratedProtocolMessageType('CSOEconItem', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEM,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItem)
  ))
_sym_db.RegisterMessage(CSOEconItem)

CMsgSortItems = _reflection.GeneratedProtocolMessageType('CMsgSortItems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSORTITEMS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSortItems)
  ))
_sym_db.RegisterMessage(CMsgSortItems)

CSOEconClaimCode = _reflection.GeneratedProtocolMessageType('CSOEconClaimCode', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONCLAIMCODE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconClaimCode)
  ))
_sym_db.RegisterMessage(CSOEconClaimCode)

CMsgStoreGetUserData = _reflection.GeneratedProtocolMessageType('CMsgStoreGetUserData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTOREGETUSERDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStoreGetUserData)
  ))
_sym_db.RegisterMessage(CMsgStoreGetUserData)

CMsgStoreGetUserDataResponse = _reflection.GeneratedProtocolMessageType('CMsgStoreGetUserDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSTOREGETUSERDATARESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStoreGetUserDataResponse)
  ))
_sym_db.RegisterMessage(CMsgStoreGetUserDataResponse)

CMsgUpdateItemSchema = _reflection.GeneratedProtocolMessageType('CMsgUpdateItemSchema', (_message.Message,), dict(
  DESCRIPTOR = _CMSGUPDATEITEMSCHEMA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgUpdateItemSchema)
  ))
_sym_db.RegisterMessage(CMsgUpdateItemSchema)

CMsgGCError = _reflection.GeneratedProtocolMessageType('CMsgGCError', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCERROR,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCError)
  ))
_sym_db.RegisterMessage(CMsgGCError)

CMsgRequestInventoryRefresh = _reflection.GeneratedProtocolMessageType('CMsgRequestInventoryRefresh', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREQUESTINVENTORYREFRESH,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRequestInventoryRefresh)
  ))
_sym_db.RegisterMessage(CMsgRequestInventoryRefresh)

CMsgConVarValue = _reflection.GeneratedProtocolMessageType('CMsgConVarValue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONVARVALUE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgConVarValue)
  ))
_sym_db.RegisterMessage(CMsgConVarValue)

CMsgReplicateConVars = _reflection.GeneratedProtocolMessageType('CMsgReplicateConVars', (_message.Message,), dict(
  DESCRIPTOR = _CMSGREPLICATECONVARS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgReplicateConVars)
  ))
_sym_db.RegisterMessage(CMsgReplicateConVars)

CMsgConsumableExhausted = _reflection.GeneratedProtocolMessageType('CMsgConsumableExhausted', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONSUMABLEEXHAUSTED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgConsumableExhausted)
  ))
_sym_db.RegisterMessage(CMsgConsumableExhausted)

CMsgItemAcknowledged = _reflection.GeneratedProtocolMessageType('CMsgItemAcknowledged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGITEMACKNOWLEDGED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgItemAcknowledged)
  ))
_sym_db.RegisterMessage(CMsgItemAcknowledged)

CMsgSetItemPositions = _reflection.GeneratedProtocolMessageType('CMsgSetItemPositions', (_message.Message,), dict(

  ItemPosition = _reflection.GeneratedProtocolMessageType('ItemPosition', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSETITEMPOSITIONS_ITEMPOSITION,
    __module__ = 'base_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSetItemPositions.ItemPosition)
    ))
  ,
  DESCRIPTOR = _CMSGSETITEMPOSITIONS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSetItemPositions)
  ))
_sym_db.RegisterMessage(CMsgSetItemPositions)
_sym_db.RegisterMessage(CMsgSetItemPositions.ItemPosition)

CMsgGCNameItemNotification = _reflection.GeneratedProtocolMessageType('CMsgGCNameItemNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCNAMEITEMNOTIFICATION,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCNameItemNotification)
  ))
_sym_db.RegisterMessage(CMsgGCNameItemNotification)

CMsgGCClientDisplayNotification = _reflection.GeneratedProtocolMessageType('CMsgGCClientDisplayNotification', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTDISPLAYNOTIFICATION,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientDisplayNotification)
  ))
_sym_db.RegisterMessage(CMsgGCClientDisplayNotification)

CMsgGCShowItemsPickedUp = _reflection.GeneratedProtocolMessageType('CMsgGCShowItemsPickedUp', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSHOWITEMSPICKEDUP,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCShowItemsPickedUp)
  ))
_sym_db.RegisterMessage(CMsgGCShowItemsPickedUp)

CMsgGCIncrementKillCountResponse = _reflection.GeneratedProtocolMessageType('CMsgGCIncrementKillCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCINCREMENTKILLCOUNTRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCIncrementKillCountResponse)
  ))
_sym_db.RegisterMessage(CMsgGCIncrementKillCountResponse)

CSOEconItemDropRateBonus = _reflection.GeneratedProtocolMessageType('CSOEconItemDropRateBonus', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMDROPRATEBONUS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemDropRateBonus)
  ))
_sym_db.RegisterMessage(CSOEconItemDropRateBonus)

CSOEconItemLeagueViewPass = _reflection.GeneratedProtocolMessageType('CSOEconItemLeagueViewPass', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMLEAGUEVIEWPASS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemLeagueViewPass)
  ))
_sym_db.RegisterMessage(CSOEconItemLeagueViewPass)

CSOEconItemEventTicket = _reflection.GeneratedProtocolMessageType('CSOEconItemEventTicket', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMEVENTTICKET,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemEventTicket)
  ))
_sym_db.RegisterMessage(CSOEconItemEventTicket)

CSOEconItemTournamentPassport = _reflection.GeneratedProtocolMessageType('CSOEconItemTournamentPassport', (_message.Message,), dict(
  DESCRIPTOR = _CSOECONITEMTOURNAMENTPASSPORT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CSOEconItemTournamentPassport)
  ))
_sym_db.RegisterMessage(CSOEconItemTournamentPassport)

CMsgGCStorePurchaseCancel = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseCancel', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASECANCEL,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseCancel)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseCancel)

CMsgGCStorePurchaseCancelResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseCancelResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASECANCELRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseCancelResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseCancelResponse)

CMsgGCStorePurchaseFinalize = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseFinalize', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEFINALIZE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseFinalize)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseFinalize)

CMsgGCStorePurchaseFinalizeResponse = _reflection.GeneratedProtocolMessageType('CMsgGCStorePurchaseFinalizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSTOREPURCHASEFINALIZERESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCStorePurchaseFinalizeResponse)
  ))
_sym_db.RegisterMessage(CMsgGCStorePurchaseFinalizeResponse)

CMsgGCBannedWordListRequest = _reflection.GeneratedProtocolMessageType('CMsgGCBannedWordListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCBANNEDWORDLISTREQUEST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCBannedWordListRequest)
  ))
_sym_db.RegisterMessage(CMsgGCBannedWordListRequest)

CMsgGCBannedWord = _reflection.GeneratedProtocolMessageType('CMsgGCBannedWord', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCBANNEDWORD,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCBannedWord)
  ))
_sym_db.RegisterMessage(CMsgGCBannedWord)

CMsgGCBannedWordListResponse = _reflection.GeneratedProtocolMessageType('CMsgGCBannedWordListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCBANNEDWORDLISTRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCBannedWordListResponse)
  ))
_sym_db.RegisterMessage(CMsgGCBannedWordListResponse)

CMsgGCToGCBannedWordListBroadcast = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBannedWordListBroadcast', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBANNEDWORDLISTBROADCAST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCBannedWordListBroadcast)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBannedWordListBroadcast)

CMsgGCToGCBannedWordListUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCToGCBannedWordListUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCBANNEDWORDLISTUPDATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCBannedWordListUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCToGCBannedWordListUpdated)

CMsgGCToGCDirtySDOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDirtySDOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDIRTYSDOCACHE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCDirtySDOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDirtySDOCache)

CMsgGCToGCDirtyMultipleSDOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCDirtyMultipleSDOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCDIRTYMULTIPLESDOCACHE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCDirtyMultipleSDOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCDirtyMultipleSDOCache)

CMsgGCToGCApplyLocalizationDiff = _reflection.GeneratedProtocolMessageType('CMsgGCToGCApplyLocalizationDiff', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCAPPLYLOCALIZATIONDIFF,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCApplyLocalizationDiff)
  ))
_sym_db.RegisterMessage(CMsgGCToGCApplyLocalizationDiff)

CMsgGCToGCApplyLocalizationDiffResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCApplyLocalizationDiffResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCAPPLYLOCALIZATIONDIFFRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCApplyLocalizationDiffResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCApplyLocalizationDiffResponse)

CMsgGCCollectItem = _reflection.GeneratedProtocolMessageType('CMsgGCCollectItem', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCOLLECTITEM,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCCollectItem)
  ))
_sym_db.RegisterMessage(CMsgGCCollectItem)

CMsgSDONoMemcached = _reflection.GeneratedProtocolMessageType('CMsgSDONoMemcached', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSDONOMEMCACHED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSDONoMemcached)
  ))
_sym_db.RegisterMessage(CMsgSDONoMemcached)

CMsgGCToGCUpdateSQLKeyValue = _reflection.GeneratedProtocolMessageType('CMsgGCToGCUpdateSQLKeyValue', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCUPDATESQLKEYVALUE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCUpdateSQLKeyValue)
  ))
_sym_db.RegisterMessage(CMsgGCToGCUpdateSQLKeyValue)

CMsgGCServerVersionUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCServerVersionUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCSERVERVERSIONUPDATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCServerVersionUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCServerVersionUpdated)

CMsgGCClientVersionUpdated = _reflection.GeneratedProtocolMessageType('CMsgGCClientVersionUpdated', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTVERSIONUPDATED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientVersionUpdated)
  ))
_sym_db.RegisterMessage(CMsgGCClientVersionUpdated)

CMsgGCToGCWebAPIAccountChanged = _reflection.GeneratedProtocolMessageType('CMsgGCToGCWebAPIAccountChanged', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCWEBAPIACCOUNTCHANGED,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCToGCWebAPIAccountChanged)
  ))
_sym_db.RegisterMessage(CMsgGCToGCWebAPIAccountChanged)

CMsgRecipeComponent = _reflection.GeneratedProtocolMessageType('CMsgRecipeComponent', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRECIPECOMPONENT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgRecipeComponent)
  ))
_sym_db.RegisterMessage(CMsgRecipeComponent)

CMsgFulfillDynamicRecipeComponent = _reflection.GeneratedProtocolMessageType('CMsgFulfillDynamicRecipeComponent', (_message.Message,), dict(
  DESCRIPTOR = _CMSGFULFILLDYNAMICRECIPECOMPONENT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgFulfillDynamicRecipeComponent)
  ))
_sym_db.RegisterMessage(CMsgFulfillDynamicRecipeComponent)

CMsgGCClientMarketDataRequest = _reflection.GeneratedProtocolMessageType('CMsgGCClientMarketDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTMARKETDATAREQUEST,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientMarketDataRequest)
  ))
_sym_db.RegisterMessage(CMsgGCClientMarketDataRequest)

CMsgGCClientMarketDataEntry = _reflection.GeneratedProtocolMessageType('CMsgGCClientMarketDataEntry', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTMARKETDATAENTRY,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientMarketDataEntry)
  ))
_sym_db.RegisterMessage(CMsgGCClientMarketDataEntry)

CMsgGCClientMarketData = _reflection.GeneratedProtocolMessageType('CMsgGCClientMarketData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTMARKETDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGCClientMarketData)
  ))
_sym_db.RegisterMessage(CMsgGCClientMarketData)

CMsgExtractGems = _reflection.GeneratedProtocolMessageType('CMsgExtractGems', (_message.Message,), dict(
  DESCRIPTOR = _CMSGEXTRACTGEMS,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgExtractGems)
  ))
_sym_db.RegisterMessage(CMsgExtractGems)

CMsgExtractGemsResponse = _reflection.GeneratedProtocolMessageType('CMsgExtractGemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGEXTRACTGEMSRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgExtractGemsResponse)
  ))
_sym_db.RegisterMessage(CMsgExtractGemsResponse)

CMsgAddSocket = _reflection.GeneratedProtocolMessageType('CMsgAddSocket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDSOCKET,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAddSocket)
  ))
_sym_db.RegisterMessage(CMsgAddSocket)

CMsgAddSocketResponse = _reflection.GeneratedProtocolMessageType('CMsgAddSocketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDSOCKETRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAddSocketResponse)
  ))
_sym_db.RegisterMessage(CMsgAddSocketResponse)

CMsgAddItemToSocketData = _reflection.GeneratedProtocolMessageType('CMsgAddItemToSocketData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDITEMTOSOCKETDATA,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAddItemToSocketData)
  ))
_sym_db.RegisterMessage(CMsgAddItemToSocketData)

CMsgAddItemToSocket = _reflection.GeneratedProtocolMessageType('CMsgAddItemToSocket', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDITEMTOSOCKET,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAddItemToSocket)
  ))
_sym_db.RegisterMessage(CMsgAddItemToSocket)

CMsgAddItemToSocketResponse = _reflection.GeneratedProtocolMessageType('CMsgAddItemToSocketResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGADDITEMTOSOCKETRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAddItemToSocketResponse)
  ))
_sym_db.RegisterMessage(CMsgAddItemToSocketResponse)

CMsgResetStrangeGemCount = _reflection.GeneratedProtocolMessageType('CMsgResetStrangeGemCount', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETSTRANGEGEMCOUNT,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgResetStrangeGemCount)
  ))
_sym_db.RegisterMessage(CMsgResetStrangeGemCount)

CMsgResetStrangeGemCountResponse = _reflection.GeneratedProtocolMessageType('CMsgResetStrangeGemCountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGRESETSTRANGEGEMCOUNTRESPONSE,
  __module__ = 'base_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:CMsgResetStrangeGemCountResponse)
  ))
_sym_db.RegisterMessage(CMsgResetStrangeGemCountResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
_CMSGCLIENTPINGDATA.fields_by_name['relay_codes'].has_options = True
_CMSGCLIENTPINGDATA.fields_by_name['relay_codes']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGCLIENTPINGDATA.fields_by_name['relay_pings'].has_options = True
_CMSGCLIENTPINGDATA.fields_by_name['relay_pings']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGCLIENTPINGDATA.fields_by_name['region_codes'].has_options = True
_CMSGCLIENTPINGDATA.fields_by_name['region_codes']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGCLIENTPINGDATA.fields_by_name['region_pings'].has_options = True
_CMSGCLIENTPINGDATA.fields_by_name['region_pings']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_CMSGGCINCREMENTKILLCOUNTRESPONSE.fields_by_name['killer_account_id'].has_options = True
_CMSGGCINCREMENTKILLCOUNTRESPONSE.fields_by_name['killer_account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSOECONITEMDROPRATEBONUS.fields_by_name['account_id'].has_options = True
_CSOECONITEMDROPRATEBONUS.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSOECONITEMDROPRATEBONUS.fields_by_name['bonus'].has_options = True
_CSOECONITEMDROPRATEBONUS.fields_by_name['bonus']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSOECONITEMDROPRATEBONUS.fields_by_name['booster_type'].has_options = True
_CSOECONITEMDROPRATEBONUS.fields_by_name['booster_type']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['account_id'].has_options = True
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['account_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['league_id'].has_options = True
_CSOECONITEMLEAGUEVIEWPASS.fields_by_name['league_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\227\"\001'))
# @@protoc_insertion_point(module_scope)
